@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
  *
  */
 
-
 #include "SysInclude.h"
 #include "SysDep.h"
 #include "SvrDefines.h"
@@ -34,134 +33,110 @@
 #include "AppDefines.h"
 #include "MailSvr.h"
 
-
-
-
-
-
 #define RUNNING_PIDS_DIR            "/var/run"
 #define DEVNULL                     "/dev/null"
 #define NOFILE                      64
 #define XMAIL_DEBUG_OPTION          "-Md"
+#define XMAIL_PIDDIR_ENV            "XMAIL_PID_DIR"
 
+static int MnEventLog(char const *pszFormat, ...);
+static char const *MnGetPIDDir(void);
+static int MnSavePID(char const *pszPidFile);
+static int MnRemovePID(char const *pszPidFile);
+static void MnSetupStdHandles(void);
+static int MnDaemonBootStrap(void);
+static int MnIsDebugStartup(int iArgCount, char *pszArgs[]);
+static int MnDaemonStartup(int iArgCount, char *pszArgs[]);
 
-
-
-
-
-
-
-static int      MnEventLog(char const * pszFormat,...);
-static int      MnSavePID(void);
-static int      MnRemovePID(void);
-static void     MnSetupStdHandles(void);
-static int      MnDaemonBootStrap(void);
-static int      MnIsDebugStartup(int iArgCount, char *pszArgs[]);
-static int      MnDaemonStartup(int iArgCount, char *pszArgs[]);
-
-
-
-
-
-
-
-static int      MnEventLog(char const * pszFormat,...)
+static int MnEventLog(char const *pszFormat, ...)
 {
 
-    openlog(APP_NAME_STR, LOG_PID, LOG_DAEMON);
+	openlog(APP_NAME_STR, LOG_PID, LOG_DAEMON);
 
+	va_list Args;
 
-    va_list         Args;
+	va_start(Args, pszFormat);
 
-    va_start(Args, pszFormat);
+	char szBuffer[2048] = "";
 
-    char            szBuffer[2048] = "";
+	vsnprintf(szBuffer, sizeof(szBuffer) - 1, pszFormat, Args);
 
-    vsnprintf(szBuffer, sizeof(szBuffer) - 1, pszFormat, Args);
+	syslog(LOG_ERR, "%s", szBuffer);
 
-    syslog(LOG_ERR, "%s", szBuffer);
+	va_end(Args);
 
-    va_end(Args);
+	closelog();
 
-
-    closelog();
-
-    return (0);
+	return (0);
 
 }
 
-
-
-
-static int      MnSavePID(void)
+static char const *MnGetPIDDir(void)
 {
+	char const *pszPIDDir = getenv(XMAIL_PIDDIR_ENV);
 
-    char            szPidFile[SYS_MAX_PATH] = "";
-
-    sprintf(szPidFile, "%s/%s.pid", RUNNING_PIDS_DIR, APP_NAME_STR);
-
-    FILE           *pFile = fopen(szPidFile, "w");
-
-    if (pFile == NULL)
-    {
-        perror(szPidFile);
-        return (-errno);
-    }
-
-    fprintf(pFile, "%u", (unsigned int) getpid());
-
-    fclose(pFile);
-
-    return (0);
+	return ((pszPIDDir != NULL) ? pszPIDDir: RUNNING_PIDS_DIR);
 
 }
 
-
-
-
-static int      MnRemovePID(void)
+static int MnSavePID(char const *pszPidFile)
 {
 
-    char            szPidFile[SYS_MAX_PATH] = "";
+	char szPidFile[SYS_MAX_PATH] = "";
 
-    sprintf(szPidFile, "%s/%s.pid", RUNNING_PIDS_DIR, APP_NAME_STR);
+	snprintf(szPidFile, sizeof(szPidFile) - 1, "%s/%s.pid", MnGetPIDDir(), pszPidFile);
 
-    if (unlink(szPidFile) != 0)
-    {
-        perror(szPidFile);
-        return (-errno);
-    }
+	FILE *pFile = fopen(szPidFile, "w");
 
-    return (0);
+	if (pFile == NULL) {
+		perror(szPidFile);
+		return (-errno);
+	}
+
+	fprintf(pFile, "%u", (unsigned int) getpid());
+
+	fclose(pFile);
+
+	return (0);
 
 }
 
-
-
-static void     MnSetupStdHandles(void)
+static int MnRemovePID(char const *pszPidFile)
 {
 
-    int         iFD = open(DEVNULL, O_RDWR, 0);
+	char szPidFile[SYS_MAX_PATH] = "";
 
-    if (iFD == -1)
-    {
-        MnEventLog("Cannot open file %s : %s", DEVNULL, strerror(errno));
-        exit(errno);
-    }
+	snprintf(szPidFile, sizeof(szPidFile) - 1, "%s/%s.pid", MnGetPIDDir(), pszPidFile);
 
-    if ((dup2(iFD, 0) == -1) || (dup2(iFD, 1) == -1) || (dup2(iFD, 2) == -1))
-    {
-        MnEventLog("File descriptor duplication error : %s", strerror(errno));
-        exit(errno);
-    }
+	if (unlink(szPidFile) != 0) {
+		perror(szPidFile);
+		return (-errno);
+	}
 
-    close(iFD);
+	return (0);
 
 }
 
+static void MnSetupStdHandles(void)
+{
 
+	int iFD = open(DEVNULL, O_RDWR, 0);
 
-static int      MnDaemonBootStrap(void)
+	if (iFD == -1) {
+		MnEventLog("Cannot open file %s : %s", DEVNULL, strerror(errno));
+		exit(errno);
+	}
+
+	if ((dup2(iFD, 0) == -1) || (dup2(iFD, 1) == -1) || (dup2(iFD, 2) == -1)) {
+		MnEventLog("File descriptor duplication error : %s", strerror(errno));
+		exit(errno);
+	}
+
+	close(iFD);
+
+}
+
+static int MnDaemonBootStrap(void)
 {
 ///////////////////////////////////////////////////////////////////////////////
 //  This code is inspired from the code of the great Richard Stevens books.
@@ -173,85 +148,77 @@ static int      MnDaemonBootStrap(void)
 //  For BSD
 ///////////////////////////////////////////////////////////////////////////////
 #ifdef SIGTTOU
-    signal(SIGTTOU, SIG_IGN);
+	signal(SIGTTOU, SIG_IGN);
 #endif
 #ifdef SIGTTIN
-    signal(SIGTTIN, SIG_IGN);
+	signal(SIGTTIN, SIG_IGN);
 #endif
 #ifdef SIGTSTP
-    signal(SIGTSTP, SIG_IGN);
+	signal(SIGTSTP, SIG_IGN);
 #endif
 
 ///////////////////////////////////////////////////////////////////////////////
 //  1st fork
 ///////////////////////////////////////////////////////////////////////////////
-    int             iChildPID = fork();
+	int iChildPID = fork();
 
-    if (iChildPID < 0)
-    {
-        MnEventLog("Cannot fork : %s", strerror(errno));
-
-        exit(errno);
-    }
-    else if (iChildPID > 0)
-        exit(0);
+	if (iChildPID < 0) {
+		MnEventLog("Cannot fork : %s", strerror(errno));
 
+		exit(errno);
+	} else if (iChildPID > 0)
+		exit(0);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Disassociate from controlling terminal and process group. Ensure the process
 //  can't reacquire a new controlling terminal.
 ///////////////////////////////////////////////////////////////////////////////
-    if (setpgrp() == -1)
-    {
-        MnEventLog("Can't change process group : %s", strerror(errno));
+	if (setpgrp() == -1) {
+		MnEventLog("Can't change process group : %s", strerror(errno));
 
-        exit(errno);
-    }
-
-    signal(SIGHUP, SIG_IGN);
+		exit(errno);
+	}
 
+	signal(SIGHUP, SIG_IGN);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  2nd fork
 ///////////////////////////////////////////////////////////////////////////////
-    iChildPID = fork();
+	iChildPID = fork();
 
-    if (iChildPID < 0)
-    {
-        MnEventLog("Cannot fork : %s", strerror(errno));
-
-        exit(errno);
-    }
-    else if (iChildPID > 0)
-        exit(0);
+	if (iChildPID < 0) {
+		MnEventLog("Cannot fork : %s", strerror(errno));
 
+		exit(errno);
+	} else if (iChildPID > 0)
+		exit(0);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Close open file descriptors
 ///////////////////////////////////////////////////////////////////////////////
-    for (int fd = 0; fd < NOFILE; fd++)
-        close(fd);
+	for (int fd = 0; fd < NOFILE; fd++)
+		close(fd);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Set std handles
 ///////////////////////////////////////////////////////////////////////////////
-    MnSetupStdHandles();
+	MnSetupStdHandles();
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Probably got set to EBADF from a close
 ///////////////////////////////////////////////////////////////////////////////
-    errno = 0;
+	errno = 0;
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Move the current directory to root, to make sure we aren't on a mounted
 //  filesystem.
 ///////////////////////////////////////////////////////////////////////////////
-    chdir("/");
+	chdir("/");
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Clear any inherited file mode creation mask.
 ///////////////////////////////////////////////////////////////////////////////
-    umask(0);
+	umask(0);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Ignore childs dead.
@@ -260,63 +227,58 @@ static int      MnDaemonBootStrap(void)
 ///////////////////////////////////////////////////////////////////////////////
 //  System V
 ///////////////////////////////////////////////////////////////////////////////
-    signal(SIGCLD, SIG_IGN);
+	signal(SIGCLD, SIG_IGN);
 
-
-
-    return (0);
+	return (0);
 
 }
 
-
-
-static int      MnIsDebugStartup(int iArgCount, char *pszArgs[])
+static int MnIsDebugStartup(int iArgCount, char *pszArgs[])
 {
 
-    for (int ii = 0; ii < iArgCount; ii++)
-        if (strcmp(pszArgs[ii], XMAIL_DEBUG_OPTION) == 0)
-            return (1);
+	for (int ii = 0; ii < iArgCount; ii++)
+		if (strcmp(pszArgs[ii], XMAIL_DEBUG_OPTION) == 0)
+			return (1);
 
-    return (0);
+	return (0);
 
 }
 
-
-
-static int      MnDaemonStartup(int iArgCount, char *pszArgs[])
+static int MnDaemonStartup(int iArgCount, char *pszArgs[])
 {
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Daemon bootstrap code if We're not in debug mode
 ///////////////////////////////////////////////////////////////////////////////
-    if (!MnIsDebugStartup(iArgCount, pszArgs))
-        MnDaemonBootStrap();
+	if (!MnIsDebugStartup(iArgCount, pszArgs))
+		MnDaemonBootStrap();
+
+///////////////////////////////////////////////////////////////////////////////
+//  Extract PID file name
+///////////////////////////////////////////////////////////////////////////////
+	char const *pszPidFile = strrchr(pszArgs[0], '/');
+
+	pszPidFile = (pszPidFile != NULL) ? (pszPidFile + 1): pszArgs[0];
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Create PID file
 ///////////////////////////////////////////////////////////////////////////////
-    MnSavePID();
-
-
-    int             iServerResult = SvrMain(iArgCount, pszArgs);
+	MnSavePID(pszPidFile);
 
+	int iServerResult = SvrMain(iArgCount, pszArgs);
 
 ///////////////////////////////////////////////////////////////////////////////
 //  Remove PID file
 ///////////////////////////////////////////////////////////////////////////////
-    MnRemovePID();
+	MnRemovePID(pszPidFile);
 
-
-    return (iServerResult);
+	return (iServerResult);
 
 }
 
-
-
-
-int             main(int iArgCount, char *pszArgs[])
+int main(int iArgCount, char *pszArgs[])
 {
 
-    return (MnDaemonStartup(iArgCount, pszArgs));
+	return (MnDaemonStartup(iArgCount, pszArgs));
 
 }
