@@ -1,6 +1,6 @@
 /*
  *  XMail by Davide Libenzi ( Intranet and Internet mail server )
- *  Copyright (C) 1999,...,2002  Davide Libenzi
+ *  Copyright (C) 1999,..,2004  Davide Libenzi
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -20,12 +20,9 @@
  *
  */
 
-
 #ifndef _POP3SVR_H
 #define _POP3SVR_H
 
-
-
 #define STD_POP3_PORT               110
 #define MAX_POP3_ACCEPT_ADDRESSES   32
 
@@ -33,32 +30,19 @@
 #define POP3F_LOG_ENABLED           (1 << 1)
 #define POP3F_HANG_ON_BADLOGIN      (1 << 2)
 
-
-
-
-
-struct POP3Config
-{
-    int             iPort;
-    unsigned long   ulFlags;
-    long            lThreadCount;
-    long            lMaxThreads;
-    int             iSessionTimeout;
-    int             iTimeout;
-    int             iBadLoginWait;
-    int             iNumAddr;
-    ServerNetPath   SvrPath[MAX_POP3_ACCEPT_ADDRESSES];
+struct POP3Config {
+	int iPort;
+	unsigned long ulFlags;
+	long lThreadCount;
+	long lMaxThreads;
+	int iSessionTimeout;
+	int iTimeout;
+	int iBadLoginWait;
+	int iNumAddr;
+	SYS_INET_ADDR SvrAddr[MAX_POP3_ACCEPT_ADDRESSES];
 
 };
 
-
-
-
-
-unsigned int    POP3ThreadProc(void *pThreadData);
-
-
-
-
+unsigned int POP3ThreadProc(void *pThreadData);
 
 #endif
